<?php

namespace Drupal\video_toolbox\Controller;

use Drupal\Core\Url;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Component\Render\FormattableMarkup;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Controller for videos list report.
 */
class VideoToolBoxReportController extends ControllerBase {

  /**
   * Type of the video identifier.
   */
  const VIDEO_IDENTIFIER_TYPE = 'video_id';

  /**
   * Creates the report page.
   *
   * @return array
   *   Render array for report output.
   */
  public function report() {
    $content = [];

    $content['add'] = [
      '#type' => 'link',
      '#title' => $this->t('Add video'),
      '#attributes' => [
        'class' => ['button button--primary'],
      ],
      '#url' => Url::fromRoute('video_toolbox.form'),
    ];

    $content['message'] = [
      '#markup' => '<br>' . $this->t('Below is a list of all uploaded videos including user, video description, video format, video link and video upload date.'),
    ];

    $headers = [
      $this->t('User'),
      $this->t('Description'),
      $this->t('Link'),
      $this->t('Uploaded date'),
      $this->t('Format'),
      $this->t('Download'),
    ];
    $videos = \Drupal::service('video.get_service')->getVideosInfo();
    $rows = [];

    foreach ($videos as $entry) {
      // Cuts the description short in case it is too long for the table.
      if (strlen($entry['description']) > 20) {
        $entry['description'] = substr($entry['description'], 0, 20) . '...';
      }
      // Obtains URLs from given routes.
      $url = Url::fromRoute('video_toolbox.videos_url', ['video_id' => $entry['video_key']])->toString();
      $urlDownload = Url::fromRoute('video_toolbox.download', [
        'identifier' => $entry['video_key'],
        'type' => self::VIDEO_IDENTIFIER_TYPE,
      ])->toString();
      $rows[] = [
        $entry['name'],
        $entry['description'],
        new FormattableMarkup('<a href=":link">@name</a>',
        [
          ':link' => $url,
          '@name' => $entry['filename'],
        ]),
        date("d/m/Y", $entry['upload_date']),
        $entry['filemime'],
        new TranslatableMarkup('<a class="button button--primary" href=":link">@download</a>',
          [
            ':link' => $urlDownload,
            '@download' => $this->t('Download'),
          ]
        ),
      ];
    }
    $content['table'] = [
      '#type' => 'table',
      '#header' => $headers,
      '#rows' => $rows,
      '#empty' => $this->t('No entries available'),
    ];
    // Don't cache this page.
    $content['#cache']['max-age'] = 0;
    return $content;
  }

}
