<?php

namespace Drupal\video_toolbox\Form;

use Drupal\Component\Utility\Random;
use Drupal\file\Entity\File;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * FOrm.
 */
class VideoGetUploaderForm extends FormBase {

  /**
   * {@inheritDoc}
   */
  public function getFormId() {
    return 'video_getter_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $random = new Random();
    $key = $random->name();

    $uid = \Drupal::currentUser()->id();
    $form['video_desc'] = [
      '#type' => 'textarea',
      '#title' => "Description",
      '#required' => TRUE,
    ];

    $form['key'] = [
      '#type' => 'hidden',
      '#value' => $key,
    ];
    $form['file'] = [
      '#type' => 'managed_file',
      '#tile' => 'upload video',
      '#upload_location' => 'public://video_saving/',
      '#upload_validators' => [
        'file_validate_extensions' => ['mp4'],
      ],
    ];

    $form['uid'] = [
      '#type' => 'hidden',
      '#value' => $uid,
    ];
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $videogetter = \Drupal::service('video.get_service');
    $key = $form_state->getValue('key');
    $check = $videogetter->getVideoInfo($key);
    if ($check != []) {
      $form_state->setErrorByName('key', $this->t('This key is being used'));
    }

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $videogetter = \Drupal::service('video.get_service');
    $type = $form_state->getValue('video_desc');
    $video = $form_state->getValue('file', 0);
    if (isset($video[0]) && !empty($video[0])) {
      $file = File::load($video[0]);
      $file->setPermanent();
      $file->save();
      $fid = $file->id();
    }
    $key = $form_state->getValue('key');
    $user_id = $form_state->getValue('uid');
    $videogetter->saveVideoInfo($type, $key, $user_id, $fid);
    $this->messenger()->addStatus($this->t('Video successfully saved.'));
  }

}
